@@ -1,4 +1,3 @@
-#ifndef __Rx_noSTAN__
 //#undef NDEBUG
 #include <Rcpp.h>
 #include <RcppEigen.h>
@@ -128,4 +127,3 @@ Matrix<T, Dynamic, 1> phiv3( double t, Matrix<T, Dynamic, Dynamic> A, VectorXd u
 
 }
 
-#endif
