@@ -1,4 +1,4 @@
 library(RxODE)
 library(testthat)
-test_check("RxODE", stop_on_failure = FALSE, wrap=TRUE, 
+test_check("RxODE", stop_on_failure = FALSE,
            reporter = testthat::LocationReporter)
