@@ -6,7 +6,9 @@ rxodeTest(
     .rx$forderForceBase(switch(radi, TRUE, FALSE))
     radix <- switch(radi, "base::order", "data.table::forder")
     context(sprintf("Test event Table et(...) sort:%s", radix))
-    library(units)
+    if (requireNamespace("units", quietly = TRUE)) {
+      library(units)
+    }
     library(dplyr)
 
 
@@ -188,9 +190,6 @@ rxodeTest(
     })
 
 
-    et3 <- et3 %>% set_units(mg)
-    ## Make sure units are right.
-
     test_that("Observation only table check", {
       expect_equal(et1$nobs, 100L)
       expect_equal(et1$ndose, 0L)
@@ -203,42 +202,46 @@ rxodeTest(
     })
 
     ## Check adding different units of time, rate, amt work
+    if (requireNamespace("units", quietly = TRUE)) {
+      et3 <- et3 %>% set_units(mg)
+      ## Make sure units are right.
 
 
-    test_that("units tests", {
-      library(units)
-      e <- et(amount.units = "mg", time_units = "hr") %>%
-        add.sampling(seq(0, 24, by = 3)) %>%
-        add.dosing(1, 3) %>%
-        et(rate = 3, amt = 2, time = 120)
-      e2 <- e %>% et(amt = set_units(0.0003, "lb"), time = 0.5)
-      expect_equal(e2$amt[e2$time == set_units(0.5, hr)], set_units(set_units(0.0003, lb), mg))
-      e2 <- e %>% et(set_units(30, min))
-      expect_true(any(e2$time == set_units(0.5, hr)))
-      e2 <- e %>% et(time = 0.25, rate = set_units(30, ug / min), amt = set_units(4, ug))
-      tmp <- e2[e2$time == set_units(0.25, hr), ]
-      expect_equal(set_units(1.8, mg / h), tmp$rate)
-      expect_equal(set_units(0.004, mg), tmp$amt)
-      e2 <- e %>% et(time = 0.25, ii = set_units(30, min), amt = 4, addl = 4)
-      expect_equal(e2$ii[e2$time == set_units(0.25, hr)], set_units(0.5, hr))
+      test_that("units tests", {
+        library(units)
+        e <- et(amount.units = "mg", time_units = "hr") %>%
+          add.sampling(seq(0, 24, by = 3)) %>%
+          add.dosing(1, 3) %>%
+          et(rate = 3, amt = 2, time = 120)
+        e2 <- e %>% et(amt = set_units(0.0003, "lb"), time = 0.5)
+        expect_equal(e2$amt[e2$time == set_units(0.5, hr)], set_units(set_units(0.0003, lb), mg))
+        e2 <- e %>% et(set_units(30, min))
+        expect_true(any(e2$time == set_units(0.5, hr)))
+        e2 <- e %>% et(time = 0.25, rate = set_units(30, ug / min), amt = set_units(4, ug))
+        tmp <- e2[e2$time == set_units(0.25, hr), ]
+        expect_equal(set_units(1.8, mg / h), tmp$rate)
+        expect_equal(set_units(0.004, mg), tmp$amt)
+        e2 <- e %>% et(time = 0.25, ii = set_units(30, min), amt = 4, addl = 4)
+        expect_equal(e2$ii[e2$time == set_units(0.25, hr)], set_units(0.5, hr))
 
-      ## Check importing wrong different ii and time units as well as different rate units work.
-      e <- et(amount.units = "mg", time_units = "hr") %>%
-        add.sampling(seq(0, 24, by = 3)) %>%
-        add.dosing(1, 3) %>%
-        et(rate = 3, amt = 2, time = 120)
+        ## Check importing wrong different ii and time units as well as different rate units work.
+        e <- et(amount.units = "mg", time_units = "hr") %>%
+          add.sampling(seq(0, 24, by = 3)) %>%
+          add.dosing(1, 3) %>%
+          et(rate = 3, amt = 2, time = 120)
 
-      etDf <- as.data.frame(e)
-      etDf$rate <- set_units(etDf$rate, ug / s)
-      etDf$ii <- set_units(etDf$ii, min)
+        etDf <- as.data.frame(e)
+        etDf$rate <- set_units(etDf$rate, ug / s)
+        etDf$ii <- set_units(etDf$ii, min)
 
-      et <- et()
-      et$import.EventTable(etDf)
+        et <- et()
+        et$import.EventTable(etDf)
 
 
-      expect_equal(et$ii, e$ii)
-      expect_equal(et$rate, e$rate)
-    })
+        expect_equal(et$ii, e$ii)
+        expect_equal(et$rate, e$rate)
+      })
+    }
 
     test_that("seq works with wait", {
       e1 <- et(amt = 100, ii = 24, addl = 6)
@@ -552,24 +555,26 @@ rxodeTest(
     expect_error(et() %>% et(amt=ds4, rate=rate, cmt=4), NA)
   })
 
-  test_that("etRep #313", {
+  if (requireNamespace("units", quietly = TRUE)) {
+    test_that("etRep #313", {
 
-    sch1 <- et(timeUnits = "hr") %>%
-      et(amt=100, ii=24, until=set_units(2,"days"))
+      sch1 <- et(timeUnits = "hr") %>%
+        et(amt=100, ii=24, until=set_units(2,"days"))
 
-    toto <- rep(sch1, times=10, wait=set_units(19,"days"))
+      toto <- rep(sch1, times=10, wait=set_units(19,"days"))
 
-    expect_equal(toto$time, seq(0, by=504, length.out=10))
+      expect_equal(toto$time, seq(0, by=504, length.out=10))
 
-    sch1 <- et(timeUnits = "hr") %>%
-      et(amt=100, ii=24, until=set_units(2,"days")) %>%
-      etExpand()
+      sch1 <- et(timeUnits = "hr") %>%
+        et(amt=100, ii=24, until=set_units(2,"days")) %>%
+        etExpand()
 
-    toto1 <- etExpand(toto)
+      toto1 <- etExpand(toto)
 
-    toto <- expect_warning(rep(sch1, times=10, wait=set_units(19,"days")))
+      toto <- expect_warning(rep(sch1, times=10, wait=set_units(19,"days")))
 
-  })
+    })
+  }
 
   test_that("'by' and 'length.out'", {
     expect_error(et(0, 3, by=0.5, length.out=3))
